\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{SVOC_podpora}[2024/02/21 v1.0 (Ing. Jakub Šejna - jakub.sejna@fsv.cvut.cz)]

\newif\if@literature \@literaturefalse
\DeclareOption{literature}{\@literaturetrue}

\newif\if@statement \@statementfalse
\DeclareOption{statement}{\@statementtrue}

\newif\if@print \@printfalse
\DeclareOption{print}{\@printtrue}


\ProcessOptions \relax


% Informace o skole - mozno menit dynamicky skrze optiony
\newcommand\University{České vysoké učení technické v Praze}
\newcommand\Faculty{Fakulta stavební}
\newcommand\Area{STUDENTSKÁ VĚDECKÁ\\ ODBORNÁ ČINNOST}
\newcommand\AKAyear{AKADEMICKÝ ROK 2023/2024}



% Volba rozložení stránky na základě zda se jedná o tezi nebo plnou disertaci
\LoadClass[12pt, oneside, a4paper]{book}
\RequirePackage[margin=2cm, left=2cm, right=2cm, top=2cm, bottom=2cm]{geometry}

% Nastavení pro fancy záhlaví a zápatí
\RequirePackage{fancyhdr}
\newlength{\chaptertopskip}
\newlength{\chapterbottomskip}
\setlength{\chaptertopskip}{0cm}
\setlength{\chapterbottomskip}{0cm}
\makeatletter

% Požadavky balíčky
\RequirePackage{graphicx}
\RequirePackage{array}
\RequirePackage[usenames,dvipsnames]{xcolor}
\RequirePackage{newtxtext}

\setcounter{secnumdepth}{0} % Číslují se pouze kapitoly (0).Sekce (1), podsekce (2) a další jsou nečíslované
\setcounter{tocdepth}{1} % Všechny úrovně do podsekcí (včetně) jsou zahrnuty v obsahu



% Makra pro definici vedouciho prace
\def \@supervisor{Unknown}
\newcommand{\supervisor}[1]{ \def \@supervisor{#1} }



\def \@authorAffiliation{Unknown}
\newcommand{\authorAffiliation}[1]{ \def \@authorAffiliation{#1} }

\def \@supervisorAffiliation{Unknown}
\newcommand{\supervisorAffiliation}[1]{ \def \@supervisorAffiliation{#1} }

\def \@supervisorspecAffiliation{Unknown}
\newcommand{\supervisorspecAffiliation}[1]{ \def \@supervisorspecAffiliation{#1} }

\def \@placeyear{Praha, \today}
\newcommand{\placeyear}[1]{ \def \@placeyear{#1} }







% Makra pro rychlejsi reference
\newcommand{\figref}[1]{\figurename~\ref{#1}}
\newcommand{\tabref}[1]{Tab. \ref{#1}}
\newcommand{\secref}[1]{část \ref{#1}}


% Uvodni stranka
\renewcommand\maketitle{\par
	% Volba stylu uvodni stranky
	\if@literature
		\@literaturetitle
	\else
		\if@statement
		\@statementtitle
		\else
		\@fullthesis
		\fi
	\fi

	\global\let\thanks\relax
	\global\let\maketitle\relax
	\global\let\@maketitle\relax
	\global\let\@thanks\@empty
	\global\let\@author\@empty
	\global\let\@date\@empty
	\global\let\@title\@empty
	\global\let\title\relax
	\global\let\author\relax
	\global\let\date\relax
	\global\let\and\relax
}

% Predni stranka pro vlastni SVOČ praci
\def\@fullthesis{%
	\frontmatter
	\begin{center}%		
		\includegraphics[width=100mm]{images/logo_FSv.jpg}
            \vspace{1cm}
            
            \Huge\bfseries\Area\\
            \vspace{2cm}
            \Large\bfseries\AKAyear\\
            \vspace{3cm}
		\Huge\bfseries\@title\\
		\vspace{1cm}
		\large\emph{\@author}\\
		\vglue 30mm
		\large 
		\vfill % Tlačí následující obsah na spodek stránky
		\@placeyear\\
				
	\end{center}%
	\thispagestyle{empty}
	
 
        % Strana 2
	\newpage
	
	\rule{0pt}{0pt}
	\vfill
	\begin{description}
		\item[Autor práce:] ~\\
		\@author\\
		\@authorAffiliation
        \item[Konzultant:] ~\\
		\@supervisor\\
		\@supervisorAffiliation
	\end{description}
	Copyright {\copyright} {\@date} {\@author}
	
	\setcounter{page}{0}
	

}




% Generování náhodného textu
\usepackage{lipsum}


